@@ -7,6 +7,7 @@ from typing import List, Optional
 from dataclasses_json import dataclass_json
 from smart_open import open
 
+from .api import IngestionApi, IngestionApiConfig
 from .kinesis import Kinesis, KinesisConfig
 from .metadata_change_event import MetadataChangeEvent
 
@@ -23,6 +24,7 @@ class RunConfig:
     """
 
     kinesis: Optional[KinesisConfig]
+    api: Optional[IngestionApiConfig]
 
     @classmethod
     def from_json_file(cls, path: str) -> "RunConfig":
@@ -35,7 +37,7 @@ class BaseExtractor(ABC):
     """Base class for metadata extractors"""
 
     def run(self, config: RunConfig) -> None:
-        """Callable function to extract metadata and send messages, should be overridden"""
+        """Callable function to extract metadata and send/post messages"""
         logger.info("Starting extractor {}".format(self.__class__.__name__))
 
         events: List[MetadataChangeEvent] = asyncio.run(self.extract(config))
@@ -44,6 +46,10 @@ class BaseExtractor(ABC):
 
         if config.kinesis is not None:
             Kinesis(config.kinesis).send_messages(events)
+
+        if config.api is not None:
+            IngestionApi(config.api).send_messages(events)
+
         logger.info("Execution finished")
 
     @abstractmethod
