@@ -54,6 +54,11 @@ def to_float(x: Any) -> float:
     return x
 
 
+def from_bool(x: Any) -> bool:
+    assert isinstance(x, bool)
+    return x
+
+
 def to_class(c: Type[T], x: Any) -> dict:
     assert isinstance(x, c)
     return cast(Any, x).to_dict()
@@ -69,11 +74,6 @@ def from_list(f: Callable[[Any], T], x: Any) -> List[T]:
     return [f(y) for y in x]
 
 
-def from_bool(x: Any) -> bool:
-    assert isinstance(x, bool)
-    return x
-
-
 class AspectType(Enum):
     DATASET_COMMENT = "DATASET_COMMENT"
     DATASET_DOCUMENTATION = "DATASET_DOCUMENTATION"
@@ -83,6 +83,7 @@ class AspectType(Enum):
     DATASET_UPSTREAM = "DATASET_UPSTREAM"
     GROUP_INFO = "GROUP_INFO"
     OWNERSHIP = "OWNERSHIP"
+    PERSON_EDITABLE_INFO = "PERSON_EDITABLE_INFO"
     PROPERTIES = "PROPERTIES"
 
 
@@ -134,6 +135,7 @@ class DatasetComment:
     entity_id: Optional[str] = None
     field: Optional[str] = None
     dataset_comment_id: Optional[str] = None
+    latest: Optional[bool] = None
     parent: Optional[str] = None
 
     @staticmethod
@@ -148,8 +150,9 @@ class DatasetComment:
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         field = from_union([from_str, from_none], obj.get("field"))
         dataset_comment_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
         parent = from_union([from_str, from_none], obj.get("parent"))
-        return DatasetComment(id, aspect_type, content, created, created_at, deleted, entity_id, field, dataset_comment_id, parent)
+        return DatasetComment(id, aspect_type, content, created, created_at, deleted, entity_id, field, dataset_comment_id, latest, parent)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -162,6 +165,7 @@ class DatasetComment:
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["field"] = from_union([from_str, from_none], self.field)
         result["id"] = from_union([from_str, from_none], self.dataset_comment_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         result["parent"] = from_union([from_str, from_none], self.parent)
         return result
 
@@ -197,6 +201,7 @@ class DatasetDocumentation:
     entity_id: Optional[str] = None
     field_documentations: Optional[List[FieldDocumentation]] = None
     dataset_documentation_id: Optional[str] = None
+    latest: Optional[bool] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'DatasetDocumentation':
@@ -208,7 +213,8 @@ class DatasetDocumentation:
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         field_documentations = from_union([lambda x: from_list(FieldDocumentation.from_dict, x), from_none], obj.get("fieldDocumentations"))
         dataset_documentation_id = from_union([from_str, from_none], obj.get("id"))
-        return DatasetDocumentation(id, aspect_type, created_at, dataset_documentations, entity_id, field_documentations, dataset_documentation_id)
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        return DatasetDocumentation(id, aspect_type, created_at, dataset_documentations, entity_id, field_documentations, dataset_documentation_id, latest)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -219,6 +225,7 @@ class DatasetDocumentation:
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["fieldDocumentations"] = from_union([lambda x: from_list(lambda x: to_class(FieldDocumentation, x), x), from_none], self.field_documentations)
         result["id"] = from_union([from_str, from_none], self.dataset_documentation_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         return result
 
 
@@ -271,6 +278,7 @@ class DatasetDownstream:
     datasets: Optional[List[DatasetLogicalID]] = None
     entity_id: Optional[str] = None
     dataset_downstream_id: Optional[str] = None
+    latest: Optional[bool] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'DatasetDownstream':
@@ -281,7 +289,8 @@ class DatasetDownstream:
         datasets = from_union([lambda x: from_list(DatasetLogicalID.from_dict, x), from_none], obj.get("datasets"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         dataset_downstream_id = from_union([from_str, from_none], obj.get("id"))
-        return DatasetDownstream(id, aspect_type, created_at, datasets, entity_id, dataset_downstream_id)
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        return DatasetDownstream(id, aspect_type, created_at, datasets, entity_id, dataset_downstream_id, latest)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -291,6 +300,7 @@ class DatasetDownstream:
         result["datasets"] = from_union([lambda x: from_list(lambda x: to_class(DatasetLogicalID, x), x), from_none], self.datasets)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.dataset_downstream_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         return result
 
 
@@ -392,6 +402,7 @@ class Ownership:
     entity_id: Optional[str] = None
     groups: Optional[List[GroupOwner]] = None
     ownership_id: Optional[str] = None
+    latest: Optional[bool] = None
     people: Optional[List[PersonOwner]] = None
 
     @staticmethod
@@ -403,8 +414,9 @@ class Ownership:
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         groups = from_union([lambda x: from_list(GroupOwner.from_dict, x), from_none], obj.get("groups"))
         ownership_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
         people = from_union([lambda x: from_list(PersonOwner.from_dict, x), from_none], obj.get("people"))
-        return Ownership(id, aspect_type, created_at, entity_id, groups, ownership_id, people)
+        return Ownership(id, aspect_type, created_at, entity_id, groups, ownership_id, latest, people)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -414,6 +426,7 @@ class Ownership:
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["groups"] = from_union([lambda x: from_list(lambda x: to_class(GroupOwner, x), x), from_none], self.groups)
         result["id"] = from_union([from_str, from_none], self.ownership_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         result["people"] = from_union([lambda x: from_list(lambda x: to_class(PersonOwner, x), x), from_none], self.people)
         return result
 
@@ -446,6 +459,7 @@ class Properties:
     description: Optional[str] = None
     entity_id: Optional[str] = None
     properties_id: Optional[str] = None
+    latest: Optional[bool] = None
     tags: Optional[List[str]] = None
 
     @staticmethod
@@ -458,8 +472,9 @@ class Properties:
         description = from_union([from_str, from_none], obj.get("description"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         properties_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
         tags = from_union([lambda x: from_list(from_str, x), from_none], obj.get("tags"))
-        return Properties(id, aspect_type, created_at, deprecated, description, entity_id, properties_id, tags)
+        return Properties(id, aspect_type, created_at, deprecated, description, entity_id, properties_id, latest, tags)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -470,6 +485,7 @@ class Properties:
         result["description"] = from_union([from_str, from_none], self.description)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.properties_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         result["tags"] = from_union([lambda x: from_list(from_str, x), from_none], self.tags)
         return result
 
@@ -571,6 +587,7 @@ class DatasetSchema:
     fields: Optional[List[SchemaField]] = None
     dataset_schema_id: Optional[str] = None
     last_modified: Optional[AuditStamp] = None
+    latest: Optional[bool] = None
     schema_type: Optional[SchemaType] = None
     sql_schema: Optional[SQLSchema] = None
 
@@ -584,9 +601,10 @@ class DatasetSchema:
         fields = from_union([lambda x: from_list(SchemaField.from_dict, x), from_none], obj.get("fields"))
         dataset_schema_id = from_union([from_str, from_none], obj.get("id"))
         last_modified = from_union([AuditStamp.from_dict, from_none], obj.get("lastModified"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
         schema_type = from_union([SchemaType, from_none], obj.get("schemaType"))
         sql_schema = from_union([SQLSchema.from_dict, from_none], obj.get("sqlSchema"))
-        return DatasetSchema(id, aspect_type, created_at, entity_id, fields, dataset_schema_id, last_modified, schema_type, sql_schema)
+        return DatasetSchema(id, aspect_type, created_at, entity_id, fields, dataset_schema_id, last_modified, latest, schema_type, sql_schema)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -597,6 +615,7 @@ class DatasetSchema:
         result["fields"] = from_union([lambda x: from_list(lambda x: to_class(SchemaField, x), x), from_none], self.fields)
         result["id"] = from_union([from_str, from_none], self.dataset_schema_id)
         result["lastModified"] = from_union([lambda x: to_class(AuditStamp, x), from_none], self.last_modified)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         result["schemaType"] = from_union([lambda x: to_enum(SchemaType, x), from_none], self.schema_type)
         result["sqlSchema"] = from_union([lambda x: to_class(SQLSchema, x), from_none], self.sql_schema)
         return result
@@ -614,6 +633,7 @@ class DatasetStatistics:
     entity_id: Optional[str] = None
     dataset_statistics_id: Optional[str] = None
     last_updated: Optional[datetime] = None
+    latest: Optional[bool] = None
     record_count: Optional[float] = None
 
     @staticmethod
@@ -626,8 +646,9 @@ class DatasetStatistics:
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         dataset_statistics_id = from_union([from_str, from_none], obj.get("id"))
         last_updated = from_union([from_datetime, from_none], obj.get("lastUpdated"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
         record_count = from_union([from_float, from_none], obj.get("recordCount"))
-        return DatasetStatistics(id, aspect_type, created_at, data_size, entity_id, dataset_statistics_id, last_updated, record_count)
+        return DatasetStatistics(id, aspect_type, created_at, data_size, entity_id, dataset_statistics_id, last_updated, latest, record_count)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -638,6 +659,7 @@ class DatasetStatistics:
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.dataset_statistics_id)
         result["lastUpdated"] = from_union([lambda x: x.isoformat(), from_none], self.last_updated)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         result["recordCount"] = from_union([to_float, from_none], self.record_count)
         return result
 
@@ -693,6 +715,7 @@ class DatasetUpstream:
     executor_url: Optional[str] = None
     field_mappings: Optional[List[FieldMapping]] = None
     dataset_upstream_id: Optional[str] = None
+    latest: Optional[bool] = None
     source_code_url: Optional[str] = None
     sources: Optional[List[DatasetLogicalID]] = None
     transformation: Optional[str] = None
@@ -707,10 +730,11 @@ class DatasetUpstream:
         executor_url = from_union([from_str, from_none], obj.get("executorUrl"))
         field_mappings = from_union([lambda x: from_list(FieldMapping.from_dict, x), from_none], obj.get("fieldMappings"))
         dataset_upstream_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
         source_code_url = from_union([from_str, from_none], obj.get("sourceCodeUrl"))
         sources = from_union([lambda x: from_list(DatasetLogicalID.from_dict, x), from_none], obj.get("sources"))
         transformation = from_union([from_str, from_none], obj.get("transformation"))
-        return DatasetUpstream(id, aspect_type, created_at, entity_id, executor_url, field_mappings, dataset_upstream_id, source_code_url, sources, transformation)
+        return DatasetUpstream(id, aspect_type, created_at, entity_id, executor_url, field_mappings, dataset_upstream_id, latest, source_code_url, sources, transformation)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -721,6 +745,7 @@ class DatasetUpstream:
         result["executorUrl"] = from_union([from_str, from_none], self.executor_url)
         result["fieldMappings"] = from_union([lambda x: from_list(lambda x: to_class(FieldMapping, x), x), from_none], self.field_mappings)
         result["id"] = from_union([from_str, from_none], self.dataset_upstream_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         result["sourceCodeUrl"] = from_union([from_str, from_none], self.source_code_url)
         result["sources"] = from_union([lambda x: from_list(lambda x: to_class(DatasetLogicalID, x), x), from_none], self.sources)
         result["transformation"] = from_union([from_str, from_none], self.transformation)
@@ -824,6 +849,7 @@ class GroupInfo:
     email: Optional[str] = None
     entity_id: Optional[str] = None
     group_info_id: Optional[str] = None
+    latest: Optional[bool] = None
     members: Optional[List[PersonID]] = None
     subgroups: Optional[List[GroupID]] = None
 
@@ -837,9 +863,10 @@ class GroupInfo:
         email = from_union([from_str, from_none], obj.get("email"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         group_info_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
         members = from_union([lambda x: from_list(PersonID.from_dict, x), from_none], obj.get("members"))
         subgroups = from_union([lambda x: from_list(GroupID.from_dict, x), from_none], obj.get("subgroups"))
-        return GroupInfo(id, admins, aspect_type, created_at, email, entity_id, group_info_id, members, subgroups)
+        return GroupInfo(id, admins, aspect_type, created_at, email, entity_id, group_info_id, latest, members, subgroups)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -850,6 +877,7 @@ class GroupInfo:
         result["email"] = from_union([from_str, from_none], self.email)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.group_info_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
         result["members"] = from_union([lambda x: from_list(lambda x: to_class(PersonID, x), x), from_none], self.members)
         result["subgroups"] = from_union([lambda x: from_list(lambda x: to_class(GroupID, x), x), from_none], self.subgroups)
         return result
