@@ -39,12 +39,7 @@ class InvalidTokenError(Exception):
 
 @dataclass
 class GoogleDirectoryRunConfig(RunConfig):
-    user_info: dict
-
-    @classmethod
-    def from_json_file(cls, path: str) -> "RunConfig":
-        with open(path, encoding="utf8") as fin:
-            return GoogleDirectoryRunConfig(json.load(fin))
+    token_file: str
 
 
 class GoogleDirectoryExtractor(BaseExtractor):
@@ -96,7 +91,10 @@ class GoogleDirectoryExtractor(BaseExtractor):
 
     @staticmethod
     def _get_directory_service(config: GoogleDirectoryRunConfig):
-        credential = Credentials.from_authorized_user_info(config.user_info, SCOPES)
+
+        with open(config.token_file) as fin:
+            credential = Credentials.from_authorized_user_info(json.load(fin), SCOPES)
+
         # If token expired, try refresh it.
         if not credential.valid:
             if credential.expired and credential.refresh_token:
